@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)            |
    |                          https://www.mrpt.org/                         |
    |                                                                        |
-   | Copyright (c) 2005-2024, Individual contributors, see AUTHORS file     |
+   | Copyright (c) 2005-2026, Individual contributors, see AUTHORS file     |
    | See: https://www.mrpt.org/Authors - All rights reserved.               |
    | Released under BSD License. See: https://www.mrpt.org/License          |
    +------------------------------------------------------------------------+ */
@@ -20,22 +20,21 @@ namespace mrpt::graphs
 // TODO - include docstring, group etc.
 class HypothesisNotFoundException : public std::runtime_error
 {
-   public:
-	HypothesisNotFoundException(
-		mrpt::graphs::TNodeID from, mrpt::graphs::TNodeID to);
-	HypothesisNotFoundException(size_t id);
-	~HypothesisNotFoundException() noexcept override;
-	void clear();
-	std::string getErrorMsg() const noexcept;
-	const char* what() const noexcept override;
+ public:
+  HypothesisNotFoundException(mrpt::graphs::TNodeID from, mrpt::graphs::TNodeID to);
+  HypothesisNotFoundException(size_t id);
+  ~HypothesisNotFoundException() noexcept override;
+  void clear();
+  std::string getErrorMsg() const noexcept;
+  const char* what() const noexcept override;
 
-   private:
-	mrpt::graphs::TNodeID m_from{INVALID_NODEID}, m_to{INVALID_NODEID};
+ private:
+  mrpt::graphs::TNodeID m_from{INVALID_NODEID}, m_to{INVALID_NODEID};
 
-	/**\brief Hypothesis ID */
-	size_t m_id{0};
+  /**\brief Hypothesis ID */
+  size_t m_id{0};
 
-	/**\brief Error message */
-	std::string m_msg;
+  /**\brief Error message */
+  std::string m_msg;
 };
 }  // namespace mrpt::graphs
