@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)            |
    |                          https://www.mrpt.org/                         |
    |                                                                        |
-   | Copyright (c) 2005-2024, Individual contributors, see AUTHORS file     |
+   | Copyright (c) 2005-2026, Individual contributors, see AUTHORS file     |
    | See: https://www.mrpt.org/Authors - All rights reserved.               |
    | Released under BSD License. See: https://www.mrpt.org/License          |
    +------------------------------------------------------------------------+ */
@@ -10,9 +10,9 @@
 #include <gtest/gtest.h>
 #include <mrpt/maps/CColouredPointsMap.h>
 #include <mrpt/maps/CGenericPointsMap.h>
-#include <mrpt/maps/CPointsMapXYZI.h>
 #include <mrpt/maps/CSimplePointsMap.h>
-#include <mrpt/maps/CWeightedPointsMap.h>
+#include <mrpt/obs/CObservation2DRangeScan.h>
+#include <mrpt/obs/stock_observations.h>
 #include <mrpt/poses/CPoint2D.h>
 
 #include <array>
@@ -31,10 +31,14 @@ constexpr std::array<float, demo9_N> demo9_ys{0, 1, 2, 0, 1, 2, 0, 1, 2};
 constexpr std::array<float, demo9_N> demo9_zs{0, 1, 2, 0, 1, 2, 0, 1, 2};
 
 template <class MAP>
-void load_demo_9pts_map(MAP& pts)
+[[nodiscard]] MAP load_demo_9pts_map()
 {
-  pts.clear();
-  for (size_t i = 0; i < demo9_N; i++) pts.insertPoint(demo9_xs[i], demo9_ys[i], demo9_zs[i]);
+  MAP pts;
+  for (size_t i = 0; i < demo9_N; i++)
+  {
+    pts.insertPoint(demo9_xs[i], demo9_ys[i], demo9_zs[i]);
+  }
+  return pts;
 }
 
 template <class MAP>
@@ -42,8 +46,7 @@ void do_test_insertPoints()
 {
   // test 1: Insert and check expected values:
   {
-    MAP pts;
-    load_demo_9pts_map(pts);
+    const MAP pts = load_demo_9pts_map<MAP>();
 
     EXPECT_EQ(pts.size(), demo9_N);
 
@@ -63,8 +66,7 @@ void do_test_insertPoints()
 
   // test 2: Copy between maps
   {
-    MAP pts1;
-    load_demo_9pts_map(pts1);
+    const MAP pts1 = load_demo_9pts_map<MAP>();
 
     MAP pts2 = pts1;
     MAP pts3 = pts1;
@@ -85,8 +87,7 @@ void do_test_insertPoints()
 
   // test 3: Insert a map into another
   {
-    MAP pts1;
-    load_demo_9pts_map(pts1);
+    const MAP pts1 = load_demo_9pts_map<MAP>();
 
     EXPECT_EQ(pts1.size(), demo9_N);
 
@@ -111,8 +112,7 @@ void do_test_insertPoints()
 
   // test 4: Insert a map into another with (0,0,0) filter:
   {
-    MAP pts1;
-    load_demo_9pts_map(pts1);
+    const MAP pts1 = load_demo_9pts_map<MAP>();
 
     EXPECT_EQ(pts1.size(), demo9_N);
 
@@ -126,27 +126,26 @@ void do_test_insertPoints()
 template <class MAP>
 void do_test_clipOutOfRangeInZ()
 {
-  MAP pts0;
-  load_demo_9pts_map(pts0);
+  const MAP pts0 = load_demo_9pts_map<MAP>();
 
   // Clip: z=[-10,-1] -> 0 pts
   {
-    MAP pts = pts0;
-    pts.clipOutOfRangeInZ(-10, -1);
+    MAP pts;
+    pts0.clipOutOfRangeInZ(-10, -1, pts);
     EXPECT_EQ(pts.size(), 0u);
   }
 
   // Clip: z=[-10,10] -> 9 pts
   {
-    MAP pts = pts0;
-    pts.clipOutOfRangeInZ(-10, 10);
+    MAP pts;
+    pts0.clipOutOfRangeInZ(-10, 10, pts);
     EXPECT_EQ(pts.size(), 9u);
   }
 
   // Clip: z=[0.5,1.5] -> 3 pts
   {
-    MAP pts = pts0;
-    pts.clipOutOfRangeInZ(0.5, 1.5);
+    MAP pts;
+    pts0.clipOutOfRangeInZ(0.5, 1.5, pts);
     EXPECT_EQ(pts.size(), 3u);
   }
 }
@@ -154,16 +153,15 @@ void do_test_clipOutOfRangeInZ()
 template <class MAP>
 void do_test_clipOutOfRange()
 {
-  MAP pts0;
-  load_demo_9pts_map(pts0);
+  const MAP pts0 = load_demo_9pts_map<MAP>();
 
   // Clip:
   {
     TPoint2D pivot(0, 0);
     const float radius = 0.5;
 
-    MAP pts = pts0;
-    pts.clipOutOfRange(pivot, radius);
+    MAP pts;
+    pts0.clipOutOfRange(pivot, radius, pts);
     EXPECT_EQ(pts.size(), 1u);
   }
 
@@ -172,8 +170,8 @@ void do_test_clipOutOfRange()
     TPoint2D pivot(-10, -10);
     const float radius = 1;
 
-    MAP pts = pts0;
-    pts.clipOutOfRange(pivot, radius);
+    MAP pts;
+    pts0.clipOutOfRange(pivot, radius, pts);
     EXPECT_EQ(pts.size(), 0u);
   }
 
@@ -182,8 +180,8 @@ void do_test_clipOutOfRange()
     TPoint2D pivot(0, 0);
     const float radius = 1.1f;
 
-    MAP pts = pts0;
-    pts.clipOutOfRange(pivot, radius);
+    MAP pts;
+    pts0.clipOutOfRange(pivot, radius, pts);
     EXPECT_EQ(pts.size(), 3u);
   }
 }
@@ -191,8 +189,7 @@ void do_test_clipOutOfRange()
 template <class MAP>
 void do_tests_loadSaveStreams()
 {
-  MAP pts0;
-  load_demo_9pts_map(pts0);
+  const MAP pts0 = load_demo_9pts_map<MAP>();
 
   EXPECT_EQ(pts0.size(), 9u);
 
@@ -251,36 +248,12 @@ void do_tests_loadSaveStreams()
 
 TEST(CSimplePointsMapTests, insertPoints) { do_test_insertPoints<CSimplePointsMap>(); }
 
-TEST(CWeightedPointsMapTests, insertPoints) { do_test_insertPoints<CWeightedPointsMap>(); }
-
-TEST(CColouredPointsMapTests, insertPoints) { do_test_insertPoints<CColouredPointsMap>(); }
-
-TEST(CPointsMapXYZI, insertPoints) { do_test_insertPoints<CPointsMapXYZI>(); }
-
 TEST(CSimplePointsMapTests, clipOutOfRangeInZ) { do_test_clipOutOfRangeInZ<CSimplePointsMap>(); }
 
-TEST(CWeightedPointsMapTests, clipOutOfRangeInZ)
-{
-  do_test_clipOutOfRangeInZ<CWeightedPointsMap>();
-}
-
-TEST(CColouredPointsMapTests, clipOutOfRangeInZ)
-{
-  do_test_clipOutOfRangeInZ<CColouredPointsMap>();
-}
-
 TEST(CSimplePointsMapTests, clipOutOfRange) { do_test_clipOutOfRange<CSimplePointsMap>(); }
 
-TEST(CWeightedPointsMapTests, clipOutOfRange) { do_test_clipOutOfRange<CWeightedPointsMap>(); }
-
-TEST(CColouredPointsMapTests, clipOutOfRange) { do_test_clipOutOfRange<CColouredPointsMap>(); }
-
 TEST(CSimplePointsMapTests, loadSaveStreams) { do_tests_loadSaveStreams<CSimplePointsMap>(); }
 
-TEST(CWeightedPointsMapTests, loadSaveStreams) { do_tests_loadSaveStreams<CWeightedPointsMap>(); }
-
-TEST(CColouredPointsMapTests, loadSaveStreams) { do_tests_loadSaveStreams<CColouredPointsMap>(); }
-
 // ----------------------------------------------------------------------
 // Tests for CGenericPointsMap custom field capabilities
 // ----------------------------------------------------------------------
@@ -423,3 +396,35 @@ TEST(CSimplePointsMapTests, RejectCustomFields)
   EXPECT_TRUE(pts.hasPointField("y"));
   EXPECT_TRUE(pts.hasPointField("z"));
 }
+
+TEST(CSimplePointsMapTests, insert2DScan)
+{
+  mrpt::obs::CObservation2DRangeScan scan1;
+  mrpt::obs::stock_observations::example2DRangeScan(scan1);
+
+  // Insert the scan:
+  mrpt::maps::CSimplePointsMap pnt;
+  pnt.insertObservation(scan1);
+  EXPECT_EQ(pnt.size(), 267UL);
+}
+
+TEST(CGenericPointsMapTests, insert2DScan)
+{
+  mrpt::obs::CObservation2DRangeScan scan1;
+  mrpt::obs::stock_observations::example2DRangeScan(scan1);
+
+  // Insert the scan:
+  mrpt::maps::CGenericPointsMap pnt;
+  pnt.registerField_float(mrpt::maps::CPointsMap::POINT_FIELD_TIMESTAMP);
+
+  pnt.insertObservation(scan1);
+  ASSERT_EQUAL_(pnt.size(), 267UL);
+
+  const auto* ts =
+      pnt.getPointsBufferRef_float_field(mrpt::maps::CPointsMap::POINT_FIELD_TIMESTAMP);
+  ASSERT_(ts != nullptr);
+
+  EXPECT_EQ(ts->size(), pnt.size());
+  EXPECT_NEAR((*ts).at(0), 0.0f, 1e-3f);
+  EXPECT_NEAR(*(*ts).rbegin(), 0.025f, 1e-3f);
+}
