@@ -2,7 +2,7 @@
 |                     Mobile Robot Programming Toolkit (MRPT)            |
 |                          https://www.mrpt.org/                         |
 |                                                                        |
-| Copyright (c) 2005-2024, Individual contributors, see AUTHORS file     |
+| Copyright (c) 2005-2026, Individual contributors, see AUTHORS file     |
 | See: https://www.mrpt.org/Authors - All rights reserved.               |
 | Released under BSD License. See: https://www.mrpt.org/License          |
 +------------------------------------------------------------------------+ */
@@ -17,9 +17,8 @@
 #include "MatrixVectorBase_impl.h"
 
 // Template instantiation:
-#define DO_MATDYN_INSTANTIATION(T_)                                            \
-	template class mrpt::math::MatrixVectorBase<                               \
-		T_, mrpt::math::CMatrixDynamic<T_>>;
+#define DO_MATDYN_INSTANTIATION(T_) \
+  template class mrpt::math::MatrixVectorBase<T_, mrpt::math::CMatrixDynamic<T_>>;
 
 DO_MATDYN_INSTANTIATION(uint16_t)
 DO_MATDYN_INSTANTIATION(int16_t)
