@@ -2,7 +2,7 @@
    |                     Mobile Robot Programming Toolkit (MRPT)            |
    |                          https://www.mrpt.org/                         |
    |                                                                        |
-   | Copyright (c) 2005-2024, Individual contributors, see AUTHORS file     |
+   | Copyright (c) 2005-2026, Individual contributors, see AUTHORS file     |
    | See: https://www.mrpt.org/Authors - All rights reserved.               |
    | Released under BSD License. See: https://www.mrpt.org/License          |
    +------------------------------------------------------------------------+ */
@@ -45,11 +45,12 @@ namespace mrpt::poses
  * \sa CPoseOrPoint
  * \ingroup interpolation_grp poses_grp
  */
-class CPose2DInterpolator : public mrpt::serialization::CSerializable,
-							public mrpt::poses::CPoseInterpolatorBase<2>
+class CPose2DInterpolator :
+    public mrpt::serialization::CSerializable,
+    public mrpt::poses::CPoseInterpolatorBase<2>
 {
-	// This must be added to any CSerializable derived class:
-	DEFINE_SERIALIZABLE(CPose2DInterpolator, mrpt::poses)
+  // This must be added to any CSerializable derived class:
+  DEFINE_SERIALIZABLE(CPose2DInterpolator, mrpt::poses)
 
-};	// End of class def.
+};  // End of class def.
 }  // namespace mrpt::poses
