@@ -2,14 +2,14 @@
    |                     Mobile Robot Programming Toolkit (MRPT)            |
    |                          https://www.mrpt.org/                         |
    |                                                                        |
-   | Copyright (c) 2005-2024, Individual contributors, see AUTHORS file     |
+   | Copyright (c) 2005-2026, Individual contributors, see AUTHORS file     |
    | See: https://www.mrpt.org/Authors - All rights reserved.               |
    | Released under BSD License. See: https://www.mrpt.org/License          |
    +------------------------------------------------------------------------+ */
 
 #include <mrpt/gui/CDisplayWindow.h>
 #include <mrpt/hwdrivers/CImageGrabber_OpenCV.h>
-#include <mrpt/io/CFileGZOutputStream.h>
+#include <mrpt/io/CCompressedOutputStream.h>
 #include <mrpt/serialization/CArchive.h>
 #include <mrpt/system/CTicTac.h>
 
@@ -54,7 +54,7 @@ void TestCapture_OpenCV()
 
   cout << "Press any key to stop capture to 'capture.rawlog'..." << endl;
 
-  CFileGZOutputStream fil("./capture.rawlog");
+  CCompressedOutputStream fil("./capture.rawlog");
 
   CDisplayWindow win("Capturing...");
 
